@@ -165,11 +165,7 @@ class LearningMachine(object):
       self.natom        = self.c.natom
       self.atom_name    = self.c.atom_name
       self.get_ro(rodic)
-      atoms             = self.c.ir.atoms
-      if FreeAtoms is None:
-         self.fixatoms  = None
-      else:
-         self.fixatoms  = FixAtoms(indices=[atom.index for atom in atoms if atom.index not in FreeAtoms])
+      self.get_fixatom()
 
       if self.mpopt==1:
          self.messages  = 1
@@ -458,6 +454,14 @@ class LearningMachine(object):
                  self.ro[i][j] = self.rodic['others']
 
 
+  def get_fixatom(self):
+      atoms             = self.c.ir.atoms
+      if self.freeatoms is None:
+         self.fixatoms  = None
+      else:
+         self.fixatoms  = FixAtoms(indices=[atom.index for atom in atoms if atom.index not in FreeAtoms])
+
+
   def save_config(self):
       with open('options.json','w') as fj:
            InPut = {'accCriteria':self.accCriteria,
@@ -488,6 +492,7 @@ class LearningMachine(object):
                     'mefac':self.mefac,
                     'learnWay':self.learnWay,
                     'colFrame':self.colFrame,
+                    'freeatoms':self.freeatoms,
                     'bore':self.bore}
            js.dump(InPut,fj,sort_keys=True,indent=2)
 
@@ -524,6 +529,7 @@ class LearningMachine(object):
            self.learnWay     = InPut['learnWay']
            self.colFrame     = InPut['colFrame']
            self.bore         = InPut['bore']
+           self.freeatoms    = InPut['freeatoms']
 
 
   def close(self):
