@@ -28,7 +28,8 @@ class MPNN(ReaxFF):
                dft='ase',atoms=None,
                cons=['val','vale','rosi','ropi','ropp', # 'ovun3', # 'val8','val9','val10',
                      'bo1','bo2','bo3','bo4','bo5','bo6','Depi','Depp','hbtol'],
-               optmol=True,opt=None,optword='nocoul',
+               optmol=True,mefac=0.1,
+               opt=None,optword='nocoul',
                nanv={'boc1':-2.0},
                batch_size=200,sample='uniform',
                hbshort=6.75,hblong=7.5,
@@ -89,7 +90,8 @@ class MPNN(ReaxFF):
          self.mpopt = mpopt
 
       ReaxFF.__init__(self,libfile=libfile,direcs=direcs,
-                      dft=dft,atoms=atoms,cons=cons,opt=opt,optword=optword,optmol=optmol,
+                      dft=dft,atoms=atoms,cons=cons,opt=opt,optword=optword,
+                      optmol=optmol,mefac=mefac,
                       nanv=nanv,batch_size=batch_size,sample=sample,
                       hbshort=hbshort,hblong=hblong,vdwcut=vdwcut,
                       rcut=rcut,rcuta=rcuta,re=re,ro_scale=ro_scale,
@@ -184,7 +186,8 @@ class MPNN(ReaxFF):
       self.loss_atol = self.supervise()
 
       self.Loss     += self.loss_atol
-      self.Loss     += self.ME
+      if self.optmol:
+         self.Loss  += self.ME*self.mefac
       self.accuracy  = self.accuracy/self.nmol
 
 
