@@ -129,6 +129,7 @@ class ReaxFF(object):
                clip_op=True,
                InitCheck=True,
                optmol=True,
+               mefac=0.1,
                nn=False,
                nnopt=True,
                bo_layer=[8,4],
@@ -165,6 +166,7 @@ class ReaxFF(object):
       self.cons          = cons
       self.optword       = optword
       self.optmol        = optmol
+      self.mefac         = mefac
       self.vdwcut        = vdwcut
       self.dft           = dft
       self.atoms         = atoms
@@ -514,7 +516,8 @@ class ReaxFF(object):
       self.loss_atol = self.supervise()
 
       self.Loss     += self.loss_atol
-      self.Loss     += self.ME
+      if self.optmol:
+         self.Loss  += self.ME*self.mefac
       self.accuracy  = self.accuracy/self.nmol
 
 
@@ -1666,8 +1669,11 @@ class ReaxFF(object):
           else:
              if accu>accMax:
                 accMax = accu
-                
-          loss_ = loss - latol - ME_
+          if self.optmol:
+             loss_ = loss - latol - ME_*self.mefac
+          else:
+             loss_ = loss - latol
+             
           if np.isnan(loss):
              self.logger.info('NAN error encountered at step %d loss is %f.' %(i,loss/self.nframe))
              # send_msg('NAN error encountered at step %d loss is %f.' %(i,loss/self.nframe))
